<?php

/**
 * @file
 * The "Desk-Net API Interaction Settings" form.
 */

namespace Drupal\desk_net\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\desk_net\Collection\NoticesCollection;

/**
 * Provides a form for configuring Desk-Net API interaction settings.
 */
class DeskNetApiInteractionSettingsForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'desk_net_api_interaction_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $html = '<h2>' . \Drupal::translation()
        ->translate('API Interaction Settings') . '</h2>';
    $html .= \Drupal::translation()
      ->translate('Configure settings for updates and deleted elements from Desk-Net 
      to Drupal, ensuring the seamless integration with the Dek-Net application.');

    $form['html'] = [
      '#markup' => $html,
    ];

    $sync_updates_from_desk_net = (bool) \Drupal::config('desk_net.settings')
      ->get('sync_updates_from_desk_net') ?? TRUE;

    $form['sync_updates_from_desk_net'] = [
      '#type' => 'checkbox',
      '#title' => \Drupal::translation()
        ->translate('Synch Updates from Desk-Net'),
      '#default_value' => $sync_updates_from_desk_net,
      '#required' => FALSE,
    ];

    $sync_deletions_from_desk_net = (bool) \Drupal::config('desk_net.settings')
      ->get('sync_deletions_from_desk_net') ?? TRUE;

    $form['sync_deletions_from_desk_net'] = [
      '#type' => 'checkbox',
      '#title' => \Drupal::translation()
        ->translate('Synch Deletions from Desk-Net'),
      '#default_value' => $sync_deletions_from_desk_net,
      '#required' => FALSE,
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => \Drupal::translation()->translate('Save'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    if (!empty($form_state->getValues())) {
      // Retrieve the values of the checkbox fields.
      $sync_updates_from_desk_net = $form_state->getValue('sync_updates_from_desk_net');
      $sync_deletions_from_desk_net = $form_state->getValue('sync_deletions_from_desk_net');

      // Save the values to configuration.
      \Drupal::configFactory()
        ->getEditable('desk_net.settings')
        ->set('sync_updates_from_desk_net', $sync_updates_from_desk_net)
        ->set('sync_deletions_from_desk_net', $sync_deletions_from_desk_net)
        ->save();

      \Drupal::messenger()->addStatus(NoticesCollection::getNotice(13));
    }
  }

}
