<?php

/**
 * @file
 * The "Desk-Net Credentials" form.
 */

namespace Drupal\desk_net\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\desk_net\Collection\NoticesCollection;
use Drupal\desk_net\Controller\RequestsController;

/**
 * Implements the Authorize Form.
 */
class DeskNetCredentialsForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'desk_net_credentials';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = \Drupal::config('desk_net.settings');

    $html = '<h2>' . \Drupal::translation()
        ->translate('Desk-Net Credentials') . '</h2>';
    $html .= \Drupal::translation()->translate('Enter here the API credentials of your Desk-Net account (not your 
   personal Desk-Net user credentials). If you do not have these API credentials
   please request them from');
    $html .= ' <a href="mailto:support@desk-net.com">support@desk-net.com</a>';

    $html .= '<p><strong>' . \Drupal::translation()
        ->translate('Please note:') . '</strong> ' .
      \Drupal::translation()->translate('Desk-Net module relies on external configurations. 
      Ensure these settings are properly adjusted for optimal performance') . '</p>';

    $form['html'] = [
      '#markup' => $html,
    ];

    $form['desk_net_api_user'] = [
      '#type' => 'textfield',
      '#title' => \Drupal::translation()->translate('Desk-Net API Login'),
      '#default_value' => $config->get('desk_net_api_user'),
      '#size' => 30,
      '#maxlength' => 50,
      '#required' => TRUE,
    ];

    $form['desk_net_api_password'] = [
      '#type' => 'password',
      '#title' => \Drupal::translation()->translate('Desk-Net API Password'),
      '#size' => 30,
      '#maxlength' => 50,
      '#required' => TRUE,
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => \Drupal::translation()->translate('Save'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    if (!empty($form_state->getValues())) {
      // Getting new credentials.
      $api_user = $form_state->getValue('desk_net_api_user');
      $api_password = $form_state->getValue('desk_net_api_password');

      if (!empty($api_user) && !empty($api_password)) {
        $token = RequestsController::getToken($api_user, $api_password);

        if ($token) {
          \Drupal::messenger()->addStatus(NoticesCollection::getNotice(7));

          // Saving Desk-Net credentials.
          \Drupal::configFactory()
            ->getEditable('desk_net.settings')
            ->set('desk_net_api_user', $api_user)
            ->set('desk_net_api_password', $api_password)
            ->save();
        }
        else {
          \Drupal::messenger()->addError(NoticesCollection::getNotice(8));
        }
      }
    }
  }

}
